# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.3.1] - 2023-03-20

### Added

### Changed

- Fixed a bug with deserializing bytes responses.

## [0.3.0] - 2023-03-09

### Added

### Changed

- Switched from snake casing api response keys to prevent mismatch scenarios.
- Fixed a bug with getting child node using deserializer identifier

## [0.2.2] - 2023-02-21

### Added

### Changed

- Fixed a bug with deserializing 'None' string values in enums.

